__author__ = 'roland'

from saml2.extension import mdui

display_name = mdui.DisplayName(text="example.com")
description = mdui.Description(text="Example.com")

uiinfo = mdui.UIInfo(display_name=display_name, description=description)
uiinfo.register_prefix({"mdui": mdui.NAMESPACE})

print(uiinfo)



from saml2.saml import NAME_FORMAT_URI
from saml2.assertion import Policy
from saml2 import config
from saml2 import saml
from saml2 import md
from saml2.attribute_converter import ac_factory
from saml2.mdstore import MetadataStore
from saml2.extension import mdui
from saml2.extension import idpdisc
from saml2.extension import dri
from saml2.extension import mdattr
from saml2.extension import ui
from saml2 import xmldsig
from saml2 import xmlenc

from pathutils import full_path

sec_config = config.Config()
#sec_config.xmlsec_binary = sigver.get_xmlsec_binary(["/opt/local/bin"])


ATTRCONV = ac_factory(full_path("attributemaps"))
R_AND_S = 'http://id.incommon.org/category/research-and-scholarship'


def _eq(l1, l2):
    return set(l1) == set(l2)


def test_ent_cat():
    mds = MetadataStore(ATTRCONV, sec_config,
                        disable_ssl_certificate_validation=True)

    mds.imp({"mdfile": [full_path("incommon.md")]})

    assigned = []
    print("Assigned")
    # Find all that are assigned R&S
    for ent in mds.keys():
        res = mds.entity_categories(ent)
        if R_AND_S in res:
            assigned.append(ent)

    assert len(assigned) > 0

    supports = []
    print("Supports")
    for ent in mds.keys():
        # Find which entity categories NN supports
        res = mds.supported_entity_categories(ent)
        # Does NN support entity category C
        if R_AND_S in res:
            supports.append(ent)

    assert len(supports) > 0


def test_entcat_filter():
    conf = {
        "default": {
            "lifetime": {"minutes": 15},  # assertion life time
            "attribute_restrictions": None,  # means all I have
            "name_form": NAME_FORMAT_URI,
            "entity_categories": ["at_egov_pvp2"]
        }}

    r = Policy(conf)

    ava = {"givenName": "Derek",
           "surName": "Jeter",
           "mail": "derek@example.com"}

    mds = MetadataStore(ATTRCONV, sec_config,
                        disable_ssl_certificate_validation=True)
    _path = "testfed-metadata.xml"
    mds.imp(
        {"local": [_path]})

    ava = r.filter(ava, "https://pvpsaml2.portalverbund.at/shibboleth", mds)

    assert ava == {}


if __name__ == "__main__":
    test_entcat_filter()


from saml2.entity_category.edugain import COC
from saml2 import BINDING_HTTP_POST
from saml2.saml import NAME_FORMAT_URI

try:
    from saml2.sigver import get_xmlsec_binary
except ImportError:
    get_xmlsec_binary = None


if get_xmlsec_binary:
    xmlsec_path = get_xmlsec_binary(["/opt/local/bin","/usr/local/bin"])
else:
    xmlsec_path = '/usr/local/bin/xmlsec1'

# Make sure the same port number appear in service_conf.py
BASE = "http://localhost:8087"

CONFIG = {
    "name": "My SP service",
    "entityid": "%s/%ssp.xml" % (BASE, ""),
    'entity_category': [COC],
    "description": "Example SP",
    "service": {
        "sp": {
            "required_attributes": ["sn", "givenname", "uid",
                                    "edupersonaffiliation"],
            "optional_attributes": ["title"],
            "endpoints": {
                "assertion_consumer_service": [
                    ("%s/acs/post" % BASE, BINDING_HTTP_POST)
                ],
            }
        },
    },
    "key_file": "pki/mykey.pem",
    "cert_file": "pki/mycert.pem",
    "xmlsec_binary": xmlsec_path,
    #"metadata": {"local": ["../idp2/idp.xml"]},
    #"metadata": {"local": ["/Users/rolandh/code/so_bridge/idp.xml"]},
    #"metadata": {"local": ["/Users/rolandh/code/s2sproxy/proxy.xml"]},
    "metadata": {
        "local": ["/Users/rolandh/code/saml2test/testtool/sp_test/idp.xml"]},
    "name_form": NAME_FORMAT_URI,
}



#!/usr/bin/env python

import time
from urlparse import parse_qs
from saml2 import BINDING_HTTP_REDIRECT
from saml2.client import Saml2Client
from saml2.server import Server
from saml2.saml import AUTHN_PASSWORD

__author__ = 'rolandh'

IDENTITY = {"eduPersonAffiliation": ["staff", "member"],
            "surName": ["Jeter"], "givenName": ["Derek"],
            "mail": ["foo@gmail.com"],
            "title": ["shortstop"]}

sp = Saml2Client(config_file="servera_conf")
idp = Server(config_file="idp_all_conf")

dest = sp._sso_location(entityid="urn:mace:example.com:saml:roland:idp",
                        binding=BINDING_HTTP_REDIRECT)

req_id, authn_request = sp.create_authn_request(destination=dest)
htargs = sp.apply_binding(BINDING_HTTP_REDIRECT, "%s" % authn_request, dest,
                          "abcd")

_dict = parse_qs(htargs["headers"][0][1].split('?')[1])


def main():
    for i in range(1000):
        req = idp.parse_authn_request(_dict["SAMLRequest"][0],
                                      BINDING_HTTP_REDIRECT)

        _sp_entity_id = req.message.issuer.text
        authn_context = (AUTHN_PASSWORD, "http://www.example.com/login")

        name_id = idp.ident.persistent_nameid("id12", _sp_entity_id)

        binding, destination = idp.pick_binding("assertion_consumer_service",
                                                entity_id=_sp_entity_id)

        _ = idp.create_authn_response(IDENTITY, "id12", destination,
                                      _sp_entity_id, name_id=name_id,
                                      authn=authn_context)

#import cProfile
#cProfile.run('main()')

start = time.time()
main()
print time.time() - start


import logging
import os
import re
import argparse

from urllib.parse import parse_qs
from saml2 import server

from saml2.authn_context import AuthnBroker, PASSWORD, UNSPECIFIED
from saml2.authn_context import authn_context_class_ref
from saml2.metadata import create_metadata_string
from service import not_found
from service import Cache
from service import do_verify_pwd
from service import info_from_cookie
from service import AUTHN_URLS
from service import NON_AUTHN_URLS

from idp_user import USERS
from idp_user import EXTRA

logger = logging.getLogger("saml2.idp")

__author__ = 'roland'


NON_AUTHN_URLS.extend([
    (r'verify_cas?(.*)$', do_verify_cas),
    (r'verify_cas?(.*)$', do_verify_pwd),
])


def metadata(environ, start_response):
    try:
        path = args.path
        if path is None or len(path) == 0:
            path = os.path.dirname(os.path.abspath( __file__ ))
        if path[-1] != "/":
            path += "/"
        metadata = create_metadata_string(path+args.config, IDP.config,
                                          args.valid, args.cert, args.keyfile,
                                          args.id, args.name, args.sign)
        start_response('200 OK', [('Content-Type', "text/xml")])
        return metadata
    except Exception as ex:
        logger.error("An error occured while creating metadata:" + ex.message)
        return not_found(environ, start_response)


def application(environ, start_response):
    """
    The main WSGI application. Dispatch the current request to
    the functions from above and store the regular expression
    captures in the WSGI environment as  `myapp.url_args` so that
    the functions from above can access the url placeholders.

    If nothing matches call the `not_found` function.

    :param environ: The HTTP application environment
    :param start_response: The application to run when the handling of the
        request is done
    :return: The response as a list of lines
    """

    path = environ.get('PATH_INFO', '').lstrip('/')

    environ["pysaml2.idp"] = IDP
    environ["pysaml2.userinfo"] = USERS
    environ["pysaml2.userinfo.extra"] = EXTRA
    environ["pysaml2.authn_broker"] = AUTHN_BROKER
    environ["pysaml2.mako.lookup"] = LOOKUP

    if path == "metadata":
        return metadata(environ, start_response)

    kaka = environ.get("HTTP_COOKIE", None)
    logger.info("<application> PATH: %s" % path)

    if kaka:
        logger.info("= KAKA =")
        user, authn_ref = info_from_cookie(kaka, IDP)
        environ["idp.authn_ref"] = authn_ref
    else:
        try:
            query = parse_qs(environ["QUERY_STRING"])
            logger.debug("QUERY: %s" % query)
            user = IDP.cache.uid2user[query["id"][0]]
        except KeyError:
            user = None

    url_patterns = AUTHN_URLS
    if not user:
        logger.info("-- No USER --")
        # insert NON_AUTHN_URLS first in case there is no user
        url_patterns = NON_AUTHN_URLS + url_patterns

    for regex, callback in url_patterns:
        match = re.search(regex, path)
        if match is not None:
            try:
                environ['myapp.url_args'] = match.groups()[0]
            except IndexError:
                environ['myapp.url_args'] = path

            logger.debug("Callback: %s" % (callback,))
            if isinstance(callback, tuple):
                cls = callback[0](environ, start_response, user)
                func = getattr(cls, callback[1])
                return func()
            return callback(environ, start_response, user)

    return not_found(environ, start_response)

# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------

if __name__ == '__main__':
    import socket
    from wsgiref.simple_server import make_server
    from mako.lookup import TemplateLookup

    parser = argparse.ArgumentParser()
    parser.add_argument('-p', dest='path', help='Path to configuration file.')
    parser.add_argument('-v', dest='valid',
                        help="How long, in days, the metadata is valid from the time of creation")
    parser.add_argument('-c', dest='cert', help='certificate')
    parser.add_argument('-i', dest='id',
                        help="The ID of the entities descriptor")
    parser.add_argument('-k', dest='keyfile',
                        help="A file with a key to sign the metadata with")
    parser.add_argument('-n', dest='name')
    parser.add_argument('-s', dest='sign', action='store_true',
                        help="sign the metadata")
    parser.add_argument('-m', dest='mako_root', default="./")
    parser.add_argument(dest="config")
    args = parser.parse_args()

    _rot = args.mako_root
    LOOKUP = TemplateLookup(directories=[_rot + 'templates', _rot + 'htdocs'],
                            module_directory=_rot + 'modules',
                            input_encoding='utf-8', output_encoding='utf-8')

    PORT = 8088

    AUTHN_BROKER = AuthnBroker()
    AUTHN_BROKER.add(authn_context_class_ref(PASSWORD),
                     cas, 10,
                     "http://%s" % socket.gethostname())
    AUTHN_BROKER.add(authn_context_class_ref(UNSPECIFIED),
                     "", 0, "http://%s" % socket.gethostname())

    IDP = server.Server(args.config, cache=Cache())
    IDP.ticket = {}

    SRV = make_server('', PORT, application)
    print("IdP listening on port: %s" % PORT)
    SRV.serve_forever()



from contextlib import closing
from saml2 import saml, sigver
from saml2 import md
from saml2 import config
from saml2.assertion import Policy
from saml2.attribute_converter import ac_factory
from saml2.extension import mdui
from saml2.extension import idpdisc
from saml2.extension import dri
from saml2.extension import mdattr
from saml2.extension import ui
from pathutils import full_path
from saml2.mdstore import MetadataStore
from saml2.server import Server
from saml2 import xmldsig
from saml2 import xmlenc


ATTRCONV = ac_factory(full_path("attributemaps"))
sec_config = config.Config()
sec_config.xmlsec_binary = sigver.get_xmlsec_binary(["/opt/local/bin"])

__author__ = 'rolandh'

MDS = MetadataStore(ATTRCONV, sec_config,
                    disable_ssl_certificate_validation=True)
MDS.imp([{"class": "saml2.mdstore.MetaDataMD",
          "metadata": [(full_path("swamid.md"),)]}])


def _eq(l1, l2):
    return set(l1) == set(l2)


def test_filter_ava():
    policy = Policy({
        "default": {
            "lifetime": {"minutes": 15},
            # "attribute_restrictions": None  # means all I have
            "entity_categories": ["swamid"]
        }
    })

    ava = {"givenName": ["Derek"], "sn": ["Jeter"],
           "mail": ["derek@nyy.mlb.com", "dj@example.com"], "c": ["USA"]}

    ava = policy.filter(ava, "https://connect.sunet.se/shibboleth", MDS)

    assert _eq(list(ava.keys()), ['mail', 'givenName', 'sn', 'c'])
    assert _eq(ava["mail"], ["derek@nyy.mlb.com", "dj@example.com"])


def test_filter_ava2():
    policy = Policy({
        "default": {
            "lifetime": {"minutes": 15},
            # "attribute_restrictions": None  # means all I have
            "entity_categories": ["refeds", "edugain"]
        }
    })

    ava = {"givenName": ["Derek"], "sn": ["Jeter"],
           "mail": ["derek@nyy.mlb.com"], "c": ["USA"],
           "eduPersonTargetedID": "foo!bar!xyz"}

    ava = policy.filter(ava, "https://connect.sunet.se/shibboleth", MDS)

    # Mismatch, policy deals with eduGAIN, metadata says SWAMID
    # So only minimum should come out
    assert _eq(list(ava.keys()), ['eduPersonTargetedID'])


def test_filter_ava3():
    policy = Policy({
        "default": {
            "lifetime": {"minutes": 15},
            # "attribute_restrictions": None  # means all I have
            "entity_categories": ["swamid"]
        }
    })

    mds = MetadataStore(ATTRCONV, sec_config,
                        disable_ssl_certificate_validation=True)
    mds.imp([{"class": "saml2.mdstore.MetaDataFile",
              "metadata": [(full_path("entity_cat_sfs_hei.xml"),)]}])

    ava = {"givenName": ["Derek"], "sn": ["Jeter"],
           "mail": ["derek@nyy.mlb.com"], "c": ["USA"],
           "eduPersonTargetedID": "foo!bar!xyz",
           "norEduPersonNIN": "19800101134"}

    ava = policy.filter(ava, "urn:mace:example.com:saml:roland:sp", mds)

    assert _eq(list(ava.keys()), ['eduPersonTargetedID', "norEduPersonNIN"])


def test_filter_ava4():
    policy = Policy({
        "default": {
            "lifetime": {"minutes": 15},
            # "attribute_restrictions": None  # means all I have
            "entity_categories": ["swamid"]
        }
    })

    mds = MetadataStore(ATTRCONV, sec_config,
                        disable_ssl_certificate_validation=True)
    mds.imp([{"class": "saml2.mdstore.MetaDataFile",
              "metadata": [(full_path("entity_cat_re_nren.xml"),)]}])

    ava = {"givenName": ["Derek"], "sn": ["Jeter"],
           "mail": ["derek@nyy.mlb.com"], "c": ["USA"],
           "eduPersonTargetedID": "foo!bar!xyz",
           "norEduPersonNIN": "19800101134"}

    ava = policy.filter(ava, "urn:mace:example.com:saml:roland:sp", mds)

    assert _eq(list(ava.keys()),
               ['eduPersonTargetedID', "givenName", "c", "mail",
                "sn"])


def test_filter_ava5():
    policy = Policy({
        "default": {
            "lifetime": {"minutes": 15},
            # "attribute_restrictions": None  # means all I have
            "entity_categories": ["swamid"]
        }
    })

    mds = MetadataStore(ATTRCONV, sec_config,
                        disable_ssl_certificate_validation=True)
    mds.imp([{"class": "saml2.mdstore.MetaDataFile",
              "metadata": [(full_path("entity_cat_re.xml"),)]}])

    ava = {"givenName": ["Derek"], "sn": ["Jeter"],
           "mail": ["derek@nyy.mlb.com"], "c": ["USA"],
           "eduPersonTargetedID": "foo!bar!xyz",
           "norEduPersonNIN": "19800101134"}

    ava = policy.filter(ava, "urn:mace:example.com:saml:roland:sp", mds)

    assert _eq(list(ava.keys()), ['eduPersonTargetedID'])


def test_idp_policy_filter():
    with closing(Server("idp_conf_ec")) as idp:
        ava = {"givenName": ["Derek"], "sn": ["Jeter"],
               "mail": ["derek@nyy.mlb.com"], "c": ["USA"],
               "eduPersonTargetedID": "foo!bar!xyz",
               "norEduPersonNIN": "19800101134"}

        policy = idp.config.getattr("policy", "idp")
        ava = policy.filter(ava, "urn:mace:example.com:saml:roland:sp",
                            idp.metadata)

        print(ava)
        assert list(ava.keys()) == [
            "eduPersonTargetedID"]  # because no entity category


if __name__ == "__main__":
    test_filter_ava3()



from saml2.saml import NAME_FORMAT_URI
from saml2 import BINDING_HTTP_POST
from saml2 import BINDING_HTTP_REDIRECT
from saml2.entity_category.edugain import COC

__author__ = 'roland'

BASE = "http://localhost"

CONFIG = {
    "entityid": "%s/%ssp.xml" % (BASE, ""),
    'entity_category': [COC],
    "description": "Example SP",
    "service": {
        "sp": {
            "required_attributes": ["surname", "givenname",
                                    "edupersonaffiliation"],
            "optional_attributes": ["title"],
            "endpoints": {
                "assertion_consumer_service": [
                    ("%s/acs/redirect" % BASE, BINDING_HTTP_REDIRECT),
                    ("%s/acs/post" % BASE, BINDING_HTTP_POST)
                ],
            },
        },
    },
    "key_file": "pki/mykey.pem",
    "cert_file": "pki/mycert.pem",
    "metadata": {"local": ["idp.xml"]},
    # "attribute_map_dir": "pysaml2/example/attributemaps",
    "name_form": NAME_FORMAT_URI,
}



from saml2 import BINDING_SOAP
from saml2.saml import NAMEID_FORMAT_TRANSIENT
from saml2.samlp import NameIDPolicy
from saml2.server import Server
from saml2.client import Saml2Client
from saml2.time_util import in_a_while

__author__ = 'rolandh'


def test_handle_logout_soap():
    sp = Saml2Client(config_file="servera_conf")
    idp = Server(config_file="idp_all_conf")

    policy = NameIDPolicy(format=NAMEID_FORMAT_TRANSIENT,
                          sp_name_qualifier=sp.config.entityid,
                          allow_create="true")

    name_id = idp.ident.construct_nameid("subject", name_id_policy=policy)

    binding, destination = idp.pick_binding("single_logout_service",
                                            [BINDING_SOAP],
                                            entity_id=sp.config.entityid)

    req_id, request = idp.create_logout_request(destination, idp.config.entityid,
                                        name_id=name_id)
    args = idp.apply_binding(BINDING_SOAP, "%s" % request, destination)

    # register the user
    session_info = {
        "name_id": name_id, "issuer": idp.config.entityid,
        "not_on_or_after": in_a_while(minutes=15),
        "ava": {
            "givenName": "Anders",
            "surName": "Andersson",
            "mail": "anders.andersson@example.com"
        }
    }
    sp.users.add_information_about_person(session_info)

    reply_args = sp.handle_logout_request(args["data"], name_id, binding,
                                          sign=False)

    print(reply_args)
    assert reply_args["method"] == "POST"
    assert reply_args["headers"] == [('content-type', 'application/soap+xml')]


#if __name__ == "__main__":
#    test_handle_logout_soap()


from dirg_authn.authn_context import AuthnBroker

__author__ = 'roland'


def ldap_validation(config):
    from dirg_authn.ldap_member import UserLDAPMemberValidation

    config["args"].update(config["conf"])
    return UserLDAPMemberValidation(**config["args"])


VALIDATOR = {
    "LDAP": ldap_validation
}


def cas_setup(item):
    from dirg_authn.user_cas import CasAuthnMethod

    try:
        v_cnf = item["validator"]
    except KeyError:
        _func = None
    else:
        _func = VALIDATOR[v_cnf["type"].upper()](item)

    _cnf = item["config"]
    return CasAuthnMethod(None, _cnf["cas_server"], item["URL"],
                          _cnf["return_to"], _func)


def userpwd_setup(item):
    from dirg_authn.user import UsernamePasswordMako

    _conf = item["config"]
    return UsernamePasswordMako(None, "login.mako", _conf["lookup"],
                                _conf["passwd"], _conf["return_to"])


def ldap_setup(item):
    from saml2.authn import LDAPAuthn

    _conf = item["config"]
    return LDAPAuthn(None, _conf["ldap_server"], _conf["return_to"],
                     _conf["dn_pattern"], "login.mako", _conf["lookup"])


AUTH_METHOD = {
    "UserPassword": userpwd_setup,
    "CAS": cas_setup,
    "LDAP": ldap_setup,
}


def authn_setup(config):
    broker = AuthnBroker()

    # Which methods to use is defined in the configuration file
    for authkey, method_conf in list(config.AUTHN_METHOD.items()):
        try:
            func = AUTH_METHOD[authkey]
        except KeyError:
            pass
        else:
            broker.add(method_conf["ACR"], func(method_conf), 
                       method_conf["WEIGHT"], method_conf["URL"])

    return broker


# -*- coding:utf-8 -*-
from mako import runtime, filters, cache
UNDEFINED = runtime.UNDEFINED
STOP_RENDERING = runtime.STOP_RENDERING
__M_dict_builtin = dict
__M_locals_builtin = locals
_magic_number = 10
_modified_time = 1443989431.110211
_enable_loop = True
_template_filename = 'templates/root.mako'
_template_uri = 'root.mako'
_source_encoding = 'utf-8'
_exports = ['post', 'pre', 'css', 'css_link']


def render_body(context,**pageargs):
    __M_caller = context.caller_stack._push_frame()
    try:
        __M_locals = __M_dict_builtin(pageargs=pageargs)
        def post():
            return render_post(context._locals(__M_locals))
        def pre():
            return render_pre(context._locals(__M_locals))
        next = context.get('next', UNDEFINED)
        set = context.get('set', UNDEFINED)
        self = context.get('self', UNDEFINED)
        __M_writer = context.writer()
        self.seen_css = set() 
        
        __M_writer('\n')
        __M_writer('\n')
        __M_writer('\n')
        __M_writer('\n')
        __M_writer('\n')
        __M_writer('<html>\n<head><title>IDP test login</title>\n    ')
        __M_writer(str(self.css()))
        __M_writer('\n    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />\n</head>\n<body>\n    ')
        __M_writer(str(pre()))
        __M_writer('\n')
        __M_writer(str(next.body()))
        __M_writer('\n')
        __M_writer(str(post()))
        __M_writer('\n</body>\n</html>\n')
        return ''
    finally:
        context.caller_stack._pop_frame()


def render_post(context):
    __M_caller = context.caller_stack._push_frame()
    try:
        context._push_buffer()
        __M_writer = context.writer()
        __M_writer('\n    <div>\n        <div class="footer">\n            <p>&#169; Copyright 2014 Ume&#229; Universitet &nbsp;</p>\n        </div>\n    </div>\n')
    finally:
        __M_buf, __M_writer = context._pop_buffer_and_writer()
        context.caller_stack._pop_frame()
    __M_writer(filters.trim(__M_buf.getvalue()))
    return ''


def render_pre(context):
    __M_caller = context.caller_stack._push_frame()
    try:
        context._push_buffer()
        __M_writer = context.writer()
        __M_writer('\n    <div class="header">\n        <h1><a href="/">Login</a></h1>\n    </div>\n')
    finally:
        __M_buf, __M_writer = context._pop_buffer_and_writer()
        context.caller_stack._pop_frame()
    __M_writer(filters.trim(__M_buf.getvalue()))
    return ''


def render_css(context):
    __M_caller = context.caller_stack._push_frame()
    try:
        context._push_buffer()
        def css_link(path,media=''):
            return render_css_link(context,path,media)
        __M_writer = context.writer()
        __M_writer('\n    ')
        __M_writer(str(css_link('/static/css/main.css', 'screen')))
        __M_writer('\n')
    finally:
        __M_buf, __M_writer = context._pop_buffer_and_writer()
        context.caller_stack._pop_frame()
    __M_writer(filters.trim(__M_buf.getvalue()))
    return ''


def render_css_link(context,path,media=''):
    __M_caller = context.caller_stack._push_frame()
    try:
        context._push_buffer()
        self = context.get('self', UNDEFINED)
        __M_writer = context.writer()
        __M_writer('\n')
        if path not in self.seen_css:
            __M_writer('        <link rel="stylesheet" type="text/css" href="')
            __M_writer(filters.html_escape(str(path)))
            __M_writer('" media="')
            __M_writer(str(media))
            __M_writer('">\n')
        __M_writer('    ')
        self.seen_css.add(path) 
        
        __M_writer('\n')
    finally:
        __M_buf, __M_writer = context._pop_buffer_and_writer()
        context.caller_stack._pop_frame()
    __M_writer(filters.trim(__M_buf.getvalue()))
    return ''


"""
__M_BEGIN_METADATA
{"uri": "root.mako", "source_encoding": "utf-8", "line_map": {"101": 4, "67": 11, "75": 8, "98": 2, "16": 0, "92": 2, "82": 8, "83": 9, "84": 9, "100": 4, "103": 4, "28": 1, "30": 1, "31": 7, "32": 10, "33": 15, "34": 22, "35": 25, "36": 27, "37": 27, "38": 31, "39": 31, "40": 34, "41": 34, "42": 35, "43": 35, "108": 6, "99": 3, "49": 16, "116": 108, "106": 6, "54": 16, "105": 6, "104": 4, "102": 4, "62": 11}, "filename": "templates/root.mako"}
__M_END_METADATA
"""



from saml2.client import Saml2Client
from saml2 import config
from saml2 import BINDING_HTTP_REDIRECT, BINDING_HTTP_POST
from saml2.entity_category.edugain import COC
from saml2.saml import NAME_FORMAT_URI
from pathutils import xmlsec_path, full_path

__author__ = 'roland'

BASE = "http://localhost:8087"


CONFIG = {
    "entityid": "%s/%ssp.xml" % (BASE, ""),
    'entity_category': [COC],
    "description": "Python SP",
    "service": {
        "sp": {
            "authn_requests_signed": "true",
            "want_assertions_signed": "true",
            "endpoints": {
                "assertion_consumer_service": [
                    ("%s/acs/redirect" % BASE, BINDING_HTTP_REDIRECT),
                    ("%s/acs/post" % BASE, BINDING_HTTP_POST)
                ],
            },
        },
    },
    "key_file": full_path("test.key"),
    "cert_file": full_path("test.pem"),
    "xmlsec_binary": xmlsec_path,
    "metadata": {"local": ["./idp.xml"]},
    "name_form": NAME_FORMAT_URI,
    "debug": 1,
}

conf = config.SPConfig()
conf.load(CONFIG)
client = Saml2Client(conf)

req = client.create_authn_request("urn:mace:example.com:saml:roland:idp")
print req


from saml2 import config, s_utils
from saml2.server import Server
from saml2.client import Saml2Client

__author__ = 'rolandh'

server = Server("idp_conf")

conf = config.SPConfig()
conf.load_file("server_conf")
client = Saml2Client(conf)

id, authn_request = client.create_authn_request(id = "id1",
                                    destination = "http://localhost:8088/sso")

print(authn_request)
intermed = s_utils.deflate_and_base64_encode("%s" % authn_request)

response = server.parse_authn_request(intermed)



from saml2 import BINDING_HTTP_POST
from pathutils import full_path

__author__ = 'rolandh'

BASE = "http://idp.com/sso"

CONFIG = {
    "entityid": "http://idp.com/sso/ssoHandler.cfm",
    "service": {
        "idp": {
            "endpoints": {
                "single_sign_on_service": [
                    ("%s/sso" % BASE, BINDING_HTTP_POST)],
            },
        },
    },
    "cert_file": full_path("test.pem"),
}



#!/usr/bin/env python

import re
import logging

#from cgi import parse_qs
from urlparse import parse_qs
from saml2.httputil import Unauthorized, NotFound, BadRequest
from saml2.httputil import ServiceError
from saml2.httputil import Response
from saml2.pack import http_form_post_message
from saml2.saml import AUTHN_PASSWORD
from saml2 import server
from saml2 import BINDING_HTTP_REDIRECT, BINDING_HTTP_POST
from saml2 import time_util
from Cookie import SimpleCookie

logger = logging.getLogger("saml2.IDP")

AUTHN = (AUTHN_PASSWORD, "http://www.example.com/login")


def _expiration(timeout, format=None):
    if timeout == "now":
        return time_util.instant(format)
    else:
        # validity time should match lifetime of assertions
        return time_util.in_a_while(minutes=timeout, format=format)

# -----------------------------------------------------------------------------
def dict_to_table(ava, lev=0, width=1):
    txt = ['<table border=%s bordercolor="black">\n' % width]
    for prop, valarr in ava.items():
        txt.append("<tr>\n")
        if isinstance(valarr, basestring):
            txt.append("<th>%s</th>\n" % str(prop))
            try:
                txt.append("<td>%s</td>\n" % valarr.encode("utf8"))
            except AttributeError:
                txt.append("<td>%s</td>\n" % valarr)
        elif isinstance(valarr, list):
            index = 0
            num = len(valarr)       
            for val in valarr:
                if not index:
                    txt.append("<th rowspan=%d>%s</td>\n" % (len(valarr), prop))
                else:
                    txt.append("<tr>\n")
                if isinstance(val, dict):
                    txt.append("<td>\n")
                    txt.extend(dict_to_table(val, lev+1, width-1))
                    txt.append("</td>\n")
                else:
                    try:
                        txt.append("<td>%s</td>\n" % val.encode("utf8"))
                    except AttributeError:
                        txt.append("<td>%s</td>\n" % val)
                if num > 1:
                    txt.append("</tr>\n")
                num -= 1
                index += 1
        elif isinstance(valarr, dict):
            txt.append("<th>%s</th>\n" % prop)
            txt.append("<td>\n")
            txt.extend(dict_to_table(valarr, lev+1, width-1))
            txt.append("</td>\n")
        txt.append("</tr>\n")
    txt.append('</table>\n')
    return txt
    
REPOZE_ID_EQUIVALENT = "uid"
FORM_SPEC = """<form name="myform" method="post" action="%s">
   <input type="hidden" name="SAMLResponse" value="%s" />
   <input type="hidden" name="RelayState" value="%s" />
</form>"""


def sso(environ, start_response, user):
    """ Supposed to return a self issuing Form POST """
    #edict = dict_to_table(environ)
    #if logger: logger.info("Environ keys: %s" % environ.keys())
    logger.info("--- In SSO ---")
    query = None
    if "QUERY_STRING" in environ:
        if logger:
            logger.info("Query string: %s" % environ["QUERY_STRING"])
        query = parse_qs(environ["QUERY_STRING"])
    elif "s2repoze.qinfo" in environ:
        query = environ["s2repoze.qinfo"]

    if not query:
        resp = Unauthorized('Unknown user')
        return resp(environ, start_response)
        
    # base 64 encoded request
    # Assume default binding, that is HTTP-redirect
    req = IDP.parse_authn_request(query["SAMLRequest"][0])

    if req is None:
        resp = ServiceError("Failed to parse the SAML request")
        return resp(environ, start_response)

    logger.info("parsed OK")
    logger.info("%s" % req)

    identity = dict(environ["repoze.who.identity"]["user"])
    logger.info("Identity: %s" % (identity,))
    userid = environ["repoze.who.identity"]['repoze.who.userid']
    if REPOZE_ID_EQUIVALENT:
        identity[REPOZE_ID_EQUIVALENT] = userid

    # What's the binding ? ProtocolBinding
    if req.message.protocol_binding == BINDING_HTTP_REDIRECT:
        _binding = BINDING_HTTP_POST
    else:
        _binding = req.message.protocol_binding

    try:
        resp_args = IDP.response_args(req.message, [_binding])
    except Exception:
        raise

    if req.message.assertion_consumer_service_url:
        if req.message.assertion_consumer_service_url != resp_args["destination"]:
            # serious error on someones behalf
            logger.error("%s != %s" % (req.message.assertion_consumer_service_url,
                                       resp_args["destination"]))
            resp = BadRequest("ConsumerURL and return destination mismatch")
            raise resp(environ, start_response)

    try:
        authn_resp = IDP.create_authn_response(identity, userid=userid,
                                               authn=AUTHN, **resp_args)
    except Exception, excp:
        logger.error("Exception: %s" % (excp,))
        raise
        
    logger.info("AuthNResponse: %s" % authn_resp)

    http_args = http_form_post_message(authn_resp, resp_args["destination"],
                                       relay_state=query["RelayState"][0],
                                       typ="SAMLResponse")

    resp = Response(http_args["data"], headers=http_args["headers"])
    return resp(environ, start_response)
    
def whoami(environ, start_response, user):
    identity = environ["repoze.who.identity"].copy()
    for prop in ["login", "password"]:
        try:
            del identity[prop]
        except KeyError:
            continue
    response = Response(dict_to_table(identity))
    return response(environ, start_response)
    
def not_found(environ, start_response):
    """Called if no URL matches."""
    resp = NotFound('Not Found')
    return resp(environ, start_response)

def not_authn(environ, start_response):
    if "QUERY_STRING" in environ:
        query = parse_qs(environ["QUERY_STRING"])
        logger.info("query: %s" % query)
    resp = Unauthorized('Unknown user')
    return resp(environ, start_response)

def slo(environ, start_response, user):
    """ Expects a HTTP-redirect logout request """

    query = None
    if "QUERY_STRING" in environ:
        logger.info("Query string: %s" % environ["QUERY_STRING"])
        query = parse_qs(environ["QUERY_STRING"])

    if not query:
        resp = Unauthorized('Unknown user')
        return resp(environ, start_response)

    try:
        req_info = IDP.parse_logout_request(query["SAMLRequest"][0],
                                            BINDING_HTTP_REDIRECT)
        logger.info("LOGOUT request parsed OK")
        logger.info("REQ_INFO: %s" % req_info.message)
    except KeyError, exc:
        logger.info("logout request error: %s" % (exc,))
        resp = BadRequest('Request parse error')
        return resp(environ, start_response)

    # look for the subject
    subject = req_info.subject_id()
    subject = subject.text.strip()
    logger.info("Logout subject: %s" % (subject,))

    status = None

    # Either HTTP-Post or HTTP-redirect is possible, prefer HTTP-Post.
    # Order matters
    bindings = [BINDING_HTTP_POST, BINDING_HTTP_REDIRECT]
    try:
        response = IDP.create_logout_response(req_info.message,
                                                        bindings)
        binding, destination = IDP.pick_binding("single_logout_service",
                                                bindings, "spsso", response)

        http_args = IDP.apply_binding(binding, "%s" % response, destination,
                                      query["RelayState"], response=True)

    except Exception, exc:
        resp = BadRequest('%s' % exc)
        return resp(environ, start_response)

    delco = delete_cookie(environ, "pysaml2idp")
    if delco:
        http_args["headers"].append(delco)

    if binding == BINDING_HTTP_POST:
        resp = Response(http_args["data"], headers=http_args["headers"])
    else:
        resp = NotFound(http_args["data"], headers=http_args["headers"])
    return resp(environ, start_response)

def delete_cookie(environ, name):
    kaka = environ.get("HTTP_COOKIE", '')
    if kaka:
        cookie_obj = SimpleCookie(kaka)
        morsel = cookie_obj.get(name, None)
        cookie = SimpleCookie()
        cookie[name] = morsel
        cookie[name]["expires"] = \
            _expiration("now", "%a, %d-%b-%Y %H:%M:%S CET")
        return tuple(cookie.output().split(": ", 1))
    return None
    
# ----------------------------------------------------------------------------

# map urls to functions
URLS = [
    (r'whoami$', whoami),
    (r'whoami/(.*)$', whoami),
    (r'sso$', sso),
    (r'sso/(.*)$', sso),
    (r'logout$', slo),
    (r'logout/(.*)$', slo),
]

# ----------------------------------------------------------------------------

def application(environ, start_response):
    """
    The main WSGI application. Dispatch the current request to
    the functions from above and store the regular expression
    captures in the WSGI environment as  `myapp.url_args` so that
    the functions from above can access the url placeholders.

    If nothing matches call the `not_found` function.
    
    :param environ: The HTTP application environment
    :param start_response: The application to run when the handling of the 
        request is done
    :return: The response as a list of lines
    """
    user = environ.get("REMOTE_USER", "")
    kaka = environ.get("HTTP_COOKIE", '')
    if not user:
        user = environ.get("repoze.who.identity", "")

    path = environ.get('PATH_INFO', '').lstrip('/')
    logger.info("<application> PATH: %s" % path)
    logger.info("Cookie: %s" % (kaka,))
    for regex, callback in URLS:
        if user:
            match = re.search(regex, path)
            if match is not None:
                try:
                    environ['myapp.url_args'] = match.groups()[0]
                except IndexError:
                    environ['myapp.url_args'] = path
                logger.info("callback: %s" % (callback,))
                return callback(environ, start_response, user)
        else:
            logger.info("-- No USER --")
            return not_authn(environ, start_response)
    return not_found(environ, start_response)

# ----------------------------------------------------------------------------

from repoze.who.config import make_middleware_with_config

APP_WITH_AUTH = make_middleware_with_config(application, {"here":"."}, 
                        './who.ini', log_file="repoze_who.log")

# ----------------------------------------------------------------------------

if __name__ == '__main__':
    import sys
    from wsgiref.simple_server import make_server

    PORT = 8088

    IDP = server.Server(sys.argv[1])
    SRV = make_server('localhost', PORT, APP_WITH_AUTH)
    print "IdP listening on port: %s" % PORT
    SRV.serve_forever()


from saml2 import config, BINDING_HTTP_POST
from saml2.client import Saml2Client
from saml2.saml import NAMEID_FORMAT_TRANSIENT

__author__ = 'roland'

conf = config.SPConfig()
conf.load_file("servera_conf")
client = Saml2Client(conf)

selected_idp = "urn:mace:example.com:saml:roland:idp"
came_from = "/"

foo = client.prepare_for_authenticate(
    entityid=selected_idp, relay_state=came_from, sign=True,
    binding=BINDING_HTTP_POST, nameid_format=NAMEID_FORMAT_TRANSIENT)

print foo


from saml2 import config

from saml2.mdstore import MetadataStore
from saml2.attribute_converter import ac_factory

from pathutils import full_path

__author__ = 'roland'

sec_config = config.Config()

ATTRCONV = ac_factory(full_path("attributemaps"))

METADATACONF = {
    # "2": [{
    #     "class": "saml2.mdstore.MetaDataExtern",
    #     "metadata": [
    #         (
    #         'http://example-sp.carrierwave.com/wordpress/wp-content/plugins'
    #         '/saml-20-single-sign-on/saml/www/module.php/saml/sp/metadata.php'
    #         '/1',
    #         full_path("inc-md-cert.pem"))]
    # }],
    "10": [{
        "class": "saml2.mdstore.MetaDataExtern",
        "metadata": [
            ("http://md.incommon.org/InCommon/InCommon-metadata-export.xml",
             full_path("inc-md-cert.pem"))]
    }
    ]
}


# def test_cert_no_signature():
#     mds = MetadataStore(ATTRCONV, sec_config,
#                         disable_ssl_certificate_validation=True)
#
#     mds.imp(METADATACONF["2"])
#     assert len(mds.keys()) >= 1


def test_signature_no_cert():
    mds = MetadataStore(ATTRCONV, sec_config,
                        disable_ssl_certificate_validation=True)

    mds.imp(METADATACONF["10"])
    assert len(mds.keys()) > 1




__author__ = 'rohe0002'

#[{"entityID":"urn:mace:incommon:osu.edu",
# "IDPSSODescriptor":{"DisplayName":"Ohio State University"},
# "Organization":{"OrganizationName":"The Ohio State University",
# "OrganizationDisplayName":"Ohio State University",
# "OrganizationURL":"http://www.osu.edu/"}}

from saml2.md import EntitiesDescriptor
from saml2 import create_class_from_xml_string

def compress(dct):
    if not isinstance(dct, dict):
        return dct

    for attr, val in dct.items():
        if isinstance(val, basestring):
            pass
        elif isinstance(val, dict):
            dct[attr] = compress(val)
        elif isinstance(val, list):
            val = [compress(v) for v in val]
            if len(val) == 1:
                dct[attr] = val[0]
            else:
                dct[attr] = val

    return dct

def add_val(dct, param, val, add_none=False):
    if not val and not add_none:
        return

    try:
        dct[param].append(val)
    except KeyError:
        dct[param] = [val]

def organization_info(org, lang="en"):
    res = {}
    for attr in ['organization_name', 'organization_display_name',
                 'organization_url']:
        for v in getattr(org, attr):
            if v.lang == lang:
                add_val(res, attr, v.text)

    return res

def do_descriptor(desc):
    res = {}

    if desc.organization:
        add_val(res, "Organization", organization_info(desc.organization))

    return res

def xml2json(inst):
    res = []
    for ed in inst.entity_descriptor:
        ent = {"entityID": ed.entity_id}
        for desc in ["idpsso_descriptor", "spsso_descriptor"]:
            for d in getattr(ed, desc):
                add_val(ent, d.__class__.__name__, do_descriptor(d), True)

        if ed.organization:
            add_val(ent, "Organization", organization_info(ed.organization))

        res.append(ent)
    return res

if __name__ == "__main__":
    import sys
    res = xml2json(create_class_from_xml_string(EntitiesDescriptor,
                                                open(sys.argv[1]).read()))

    res = [compress(r) for r in res]
    for item in res:
        print item



from saml2 import BINDING_HTTP_POST
from saml2.metadata import entity_descriptor
from saml2.config import SPConfig
from saml2.client import Saml2Client

__author__ = 'roland'

fil = "sp_multi_index_endp_conf"

conf = SPConfig()
conf.load_file(fil)

client = Saml2Client(conf)

endp = client.config.endpoint("assertion_consumer_service")

assert len(endp) == 3
assert endp[0] == "http://lingon.catalogix.se:8087/A"


cnf = SPConfig().load_file(fil, metadata_construction=True)
edesc = entity_descriptor(cnf)

acs = edesc.spsso_descriptor.assertion_consumer_service
assert len(acs) == 3

assert acs[0].binding == BINDING_HTTP_POST
assert acs[0].index == '1'
assert acs[0].location == "http://lingon.catalogix.se:8087/A"

assert acs[1].binding == BINDING_HTTP_POST
assert acs[1].index == '2'
assert acs[1].location == "http://lingon.catalogix.se:8087/B"

assert acs[2].binding == BINDING_HTTP_POST
assert acs[2].index == '3'
assert acs[2].location == "http://lingon.catalogix.se:8087/C"

cnf = SPConfig().load_file("sp_3_tup_conf", metadata_construction=True)
edesc = entity_descriptor(cnf)
acs = edesc.spsso_descriptor.assertion_consumer_service

print(edesc)


foo = {'https://connect.sunet.se/shibboleth': {'spsso': [{










































































































































































                                                         'single_logout_service': [
                                                             {
                                                             'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:SOAP',
                                                             '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService',
                                                             'location': 'https://connect.sunet.se/Shibboleth.sso/SLO/SOAP'},
                                                             {
                                                             'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect',
                                                             '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService',
                                                             'location': 'https://connect.sunet.se/Shibboleth.sso/SLO/Redirect'},
                                                             {
                                                             'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST',
                                                             '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService',
                                                             'location': 'https://connect.sunet.se/Shibboleth.sso/SLO/POST'},
                                                             {
                                                             'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact',
                                                             '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService',
                                                             'location': 'https://connect.sunet.se/Shibboleth.sso/SLO/Artifact'}],
                                                         '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor',
                                                         'protocol_support_enumeration': 'urn:oasis:names:tc:SAML:2.0:protocol urn:oasis:names:tc:SAML:1.1:protocol urn:oasis:names:tc:SAML:1.0:protocol',
                                                         'assertion_consumer_service': [
                                                             {'index': '1',
                                                              'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST',
                                                              '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/SAML2/POST'},
                                                             {'index': '2',
                                                              'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign',
                                                              '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign'},
                                                             {'index': '3',
                                                              'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact',
                                                              '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/SAML2/Artifact'},
                                                             {'index': '4',
                                                              'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:PAOS',
                                                              '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/SAML2/ECP'},
                                                             {'index': '5',
                                                              'binding': 'urn:oasis:names:tc:SAML:1.0:profiles:browser-post',
                                                              '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/SAML/POST'},
                                                             {'index': '6',
                                                              'binding': 'urn:oasis:names:tc:SAML:1.0:profiles:artifact-01',
                                                              '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/SAML/Artifact'}],
                                                         'attribute_consuming_service': [
                                                             {'index': '0',
                                                              'service_description': [
                                                                  {'lang': 'en',
                                                                   'text': 'SUNET E-Meeting Service (Adobe Connect Pro)',
                                                                   '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription'}],
                                                              '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService',
                                                              'requested_attribute': [
                                                                  {
                                                                  '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute',
                                                                  'name': 'urn:oid:1.3.6.1.4.1.5923.1.1.1.6',
                                                                  'name_format': 'urn:oasis:names:tc:SAML:2.0:attrname-format:uri'},
                                                                  {
                                                                  '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute',
                                                                  'name': 'urn:oid:0.9.2342.19200300.100.1.3',
                                                                  'name_format': 'urn:oasis:names:tc:SAML:2.0:attrname-format:uri'},
                                                                  {
                                                                  '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute',
                                                                  'name': 'urn:oid:2.5.4.42',
                                                                  'name_format': 'urn:oasis:names:tc:SAML:2.0:attrname-format:uri'},
                                                                  {
                                                                  '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute',
                                                                  'name': 'urn:oid:2.5.4.4',
                                                                  'name_format': 'urn:oasis:names:tc:SAML:2.0:attrname-format:uri'},
                                                                  {
                                                                  '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute',
                                                                  'name': 'urn:oid:1.3.6.1.4.1.5923.1.1.1.9',
                                                                  'name_format': 'urn:oasis:names:tc:SAML:2.0:attrname-format:uri'}],
                                                              'service_name': [
                                                                  {'lang': 'en',
                                                                   'text': 'SUNET E-Meeting Service',
                                                                   '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&ServiceName'}]}],
                                                         'extensions': {
                                                         '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&Extensions',
                                                         'extension_elements': [
                                                             {'index': '1',
                                                              'binding': 'urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol',
                                                              '__type__': 'urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/DS/ds.swamid.se'},
                                                             {'index': '1',
                                                              'binding': 'urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol',
                                                              '__type__': 'urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/DS/ds.sunet.se'},
                                                             {'index': '1',
                                                              'binding': 'urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol',
                                                              '__type__': 'urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse',
                                                              'location': 'https://connect.sunet.se/Shibboleth.sso/DS/kalmar2'}]},
                                                         'key_descriptor': [{
                                                                            'key_info': {
                                                                            'key_name': [
                                                                                {
                                                                                'text': 'connect01.acp.sunet.se',
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&KeyName'},
                                                                                {
                                                                                'text': 'https://connect.sunet.se/shibboleth',
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&KeyName'}],
                                                                            'x509_data': [
                                                                                {
                                                                                'x509_subject_name': {
                                                                                'text': 'CN=connect01.acp.sunet.se',
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&X509SubjectName'},
                                                                                'x509_certificate': {
                                                                                'text': 'MIIDLjCCAhagAwIBAgIJALJTE8wpfDmAMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n                        BAMTFmNvbm5lY3QwMS5hY3Auc3VuZXQuc2UwHhcNMDkwOTAyMTIwNTIwWhcNMTkw\n                        ODMxMTIwNTIwWjAhMR8wHQYDVQQDExZjb25uZWN0MDEuYWNwLnN1bmV0LnNlMIIB\n                        IjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzaNMBLHGgzRrAHLQDUiM+xu6\n                        ghKwdRqBcg171qVDeA4wSoVJLVeAY2xWKjudYzXtcwqL7qkDcHD3wOd0FLQSFfxE\n                        o67z4chBMNrkK9b9NgdHWp/Nb8gsdYNZt2ZjJVOD/oWTFXRHZDJhqkXFvVjL1gKu\n                        E3a2vDK6LRqYCLx5cyFleuRoqBvMrDxKLHvmqxo+Qt2e+ntL1sDVyKeMxgZc2s0/\n                        xGYFFzSVDT08XrWlgpN0AmxhfC0ULDb8YzQiJxsdeZ3C57RnC0InabCCvzPQsy9t\n                        c1VU/TNXkkXQn3H5aC+LUu8olnYndtFac56k/OaAUPe15/1MQVXvL8vbGG6JkQID\n                        AQABo2kwZzBGBgNVHREEPzA9ghZjb25uZWN0MDEuYWNwLnN1bmV0LnNlhiNodHRw\n                        czovL2Nvbm5lY3Quc3VuZXQuc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUxPAGA++l\n                        tPOMkUezKJJrwSNAz/0wDQYJKoZIhvcNAQEFBQADggEBADJJgcI6VADyB8749iGB\n                        UbK97Zav6/YoX3jMH21tpO0+iZyPlfCxlDmNIBSSrHmNIs7g8sBSi+z8ko2IaSKS\n                        Ya0fI0N+cvBoi+3Wfszq0LpUSu/5pMWiw3DacOCNesR76h+FKD/UPgUL+LDw7ebz\n                        K3aeVvtsIjPijrcCaUKrZg5dv/5CRx/oQLbV20L3xk5UTTO/RNrR1gef37yEowDd\n                        d8hQaQgw5uujjjdkr/6u03kjO6rEZAySsiBPGcpBDXAbk4lnJVQltP0MBE4pu+es\n                        0oZu+lC7LltiBjJxdh/7SaqdLbn7G7cApwQKqXHVFITX9ncVMM04FtM9MzMc9d4y\n                        bUs=',
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&X509Certificate'},
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&X509Data'}],
                                                                            '__type__': 'http://www.w3.org/2000/09/xmldsig#&KeyInfo'},
                                                                            'use': 'signing',
                                                                            '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor'},
                                                                            {
                                                                            'key_info': {
                                                                            'key_name': [
                                                                                {
                                                                                'text': 'connect01.acp.sunet.se',
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&KeyName'},
                                                                                {
                                                                                'text': 'https://connect.sunet.se/shibboleth',
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&KeyName'}],
                                                                            'x509_data': [
                                                                                {
                                                                                'x509_subject_name': {
                                                                                'text': 'CN=connect01.acp.sunet.se',
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&X509SubjectName'},
                                                                                'x509_certificate': {
                                                                                'text': 'MIIDLjCCAhagAwIBAgIJALJTE8wpfDmAMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n                        BAMTFmNvbm5lY3QwMS5hY3Auc3VuZXQuc2UwHhcNMDkwOTAyMTIwNTIwWhcNMTkw\n                        ODMxMTIwNTIwWjAhMR8wHQYDVQQDExZjb25uZWN0MDEuYWNwLnN1bmV0LnNlMIIB\n                        IjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzaNMBLHGgzRrAHLQDUiM+xu6\n                        ghKwdRqBcg171qVDeA4wSoVJLVeAY2xWKjudYzXtcwqL7qkDcHD3wOd0FLQSFfxE\n                        o67z4chBMNrkK9b9NgdHWp/Nb8gsdYNZt2ZjJVOD/oWTFXRHZDJhqkXFvVjL1gKu\n                        E3a2vDK6LRqYCLx5cyFleuRoqBvMrDxKLHvmqxo+Qt2e+ntL1sDVyKeMxgZc2s0/\n                        xGYFFzSVDT08XrWlgpN0AmxhfC0ULDb8YzQiJxsdeZ3C57RnC0InabCCvzPQsy9t\n                        c1VU/TNXkkXQn3H5aC+LUu8olnYndtFac56k/OaAUPe15/1MQVXvL8vbGG6JkQID\n                        AQABo2kwZzBGBgNVHREEPzA9ghZjb25uZWN0MDEuYWNwLnN1bmV0LnNlhiNodHRw\n                        czovL2Nvbm5lY3Quc3VuZXQuc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUxPAGA++l\n                        tPOMkUezKJJrwSNAz/0wDQYJKoZIhvcNAQEFBQADggEBADJJgcI6VADyB8749iGB\n                        UbK97Zav6/YoX3jMH21tpO0+iZyPlfCxlDmNIBSSrHmNIs7g8sBSi+z8ko2IaSKS\n                        Ya0fI0N+cvBoi+3Wfszq0LpUSu/5pMWiw3DacOCNesR76h+FKD/UPgUL+LDw7ebz\n                        K3aeVvtsIjPijrcCaUKrZg5dv/5CRx/oQLbV20L3xk5UTTO/RNrR1gef37yEowDd\n                        d8hQaQgw5uujjjdkr/6u03kjO6rEZAySsiBPGcpBDXAbk4lnJVQltP0MBE4pu+es\n                        0oZu+lC7LltiBjJxdh/7SaqdLbn7G7cApwQKqXHVFITX9ncVMM04FtM9MzMc9d4y\n                        bUs=',
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&X509Certificate'},
                                                                                '__type__': 'http://www.w3.org/2000/09/xmldsig#&X509Data'}],
                                                                            '__type__': 'http://www.w3.org/2000/09/xmldsig#&KeyInfo'},
                                                                            'use': 'encryption',
                                                                            '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor'}],
                                                         'manage_name_id_service': [
                                                             {
                                                             'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:SOAP',
                                                             '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService',
                                                             'location': 'https://connect.sunet.se/Shibboleth.sso/NIM/SOAP'},
                                                             {
                                                             'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect',
                                                             '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService',
                                                             'location': 'https://connect.sunet.se/Shibboleth.sso/NIM/Redirect'},
                                                             {
                                                             'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST',
                                                             '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService',
                                                             'location': 'https://connect.sunet.se/Shibboleth.sso/NIM/POST'},
                                                             {
                                                             'binding': 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact',
                                                             '__type__': 'urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService',
                                                             'location': 'https://connect.sunet.se/Shibboleth.sso/NIM/Artifact'}]}]}}



from http.cookies import SimpleCookie
import base64
import os
import logging
import time
from saml2 import time_util
from saml2.httputil import NotFound

__author__ = 'roland'

logger = logging.getLogger(__name__)


def not_found(environ, start_response):
    """Called if no URL matches."""
    resp = NotFound()
    return resp(environ, start_response)


def staticfile(environ, start_response, args):
    try:
        path = args.path
        if path is None or len(path) == 0:
            path = os.path.dirname(os.path.abspath(__file__))
        if path[-1] != "/":
            path += "/"
        _path = environ.get('PATH_INFO', '').lstrip('/')
        while True:
            if _path.startswith("./"):
                _path = path[2:]
            elif _path.startswith("../"):
                _path = _path[3:]
            else:
                break

        path += _path
        start_response('200 OK', [('Content-Type', "text/xml")])
        return open(path, 'r').read()
    except Exception as ex:
        logger.error("An error occured while creating metadata:" + ex.message)
        return not_found(environ, start_response)


def expiration(timeout, tformat="%a, %d-%b-%Y %H:%M:%S GMT"):
    """

    :param timeout:
    :param tformat:
    :return:
    """
    if timeout == "now":
        return time_util.instant(tformat)
    elif timeout == "dawn":
        return time.strftime(tformat, time.gmtime(0))
    else:
        # validity time should match lifetime of assertions
        return time_util.in_a_while(minutes=timeout, format=tformat)


# ----------------------------------------------------------------------------
# Cookie handling
# ----------------------------------------------------------------------------


def delete_cookie(environ, name):
    kaka = environ.get("HTTP_COOKIE", '')
    logger.debug("delete KAKA: %s" % kaka)
    if kaka:
        cookie_obj = SimpleCookie(kaka)
        morsel = cookie_obj.get(name, None)
        cookie = SimpleCookie()
        cookie[name] = ""
        cookie[name]['path'] = "/"
        logger.debug("Expire: %s" % morsel)
        cookie[name]["expires"] = expiration("dawn")
        return tuple(cookie.output().split(": ", 1))
    return None


def set_cookie(name, _, *args):
    cookie = SimpleCookie()
    cookie[name] = base64.b64encode(":".join(args))
    cookie[name]['path'] = "/"
    cookie[name]["expires"] = expiration(5)  # 5 minutes from now
    logger.debug("Cookie expires: %s" % cookie[name]["expires"])
    return tuple(cookie.output().split(": ", 1))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
from saml2 import BINDING_HTTP_REDIRECT
from saml2 import BINDING_SOAP
from saml2.saml import NAME_FORMAT_URI
from saml2.saml import NAMEID_FORMAT_TRANSIENT
from saml2.saml import NAMEID_FORMAT_PERSISTENT
import os.path

try:
    from saml2.sigver import get_xmlsec_binary
except ImportError:
    get_xmlsec_binary = None

if get_xmlsec_binary:
    xmlsec_path = get_xmlsec_binary(["/opt/local/bin"])
else:
    xmlsec_path = '/usr/bin/xmlsec1'

BASEDIR = os.path.dirname(os.path.dirname(__file__))


def full_path(local_file):
    return os.path.join(BASEDIR, local_file)

# HOST = "staging.sso-simple.org"
# PORT = 80

HOST = "localhost"
PORT = 5000

BASE = "http://%s:%s" % (HOST, PORT)
# BASE = "http://%s" % HOST


CONFIG = {
    "entityid": "%s/metadata.xml" % BASE,
    "description": "CarrierWave IDP",
    "valid_for": 168,
    "service": {
        "idp": {
            "name": "CarrierWave IdP",
            "endpoints": {
                "single_sign_on_service": [
                    ("%s/sso/redirect/" % BASE, BINDING_HTTP_REDIRECT)
                ],
                "single_logout_service": [
                    ("%s/slo/soap/" % BASE, BINDING_SOAP),
                ]
            },
            "policy": {
                "default": {
                    "lifetime": {"minutes": 15},
                    "attribute_restrictions": None,
                    "name_format": NAME_FORMAT_URI,
                    "entity_categories": ["swamid", "edugain"]
                },
            },
            "subject_data": "./idp.subject",
            "name_id_format": [NAMEID_FORMAT_TRANSIENT, NAMEID_FORMAT_PERSISTENT]
        },
    },
    "debug": 1,
    "key_file": full_path("idp2/pki/mykey.pem"),
    "cert_file": full_path("idp2/pki/mycert.pem"),
    "metadata": {
        "remote": [{
            'url': 'http://example-sp.carrierwave.com/wordpress/wp-content/plugins/saml-20-single-sign-on/saml/www/module.php/saml/sp/metadata.php/1'
        }]
    },
    "organization": {
        "display_name": "CarrierWave",
        "name": "CarrierWave",
        "url": "http://www.carrierwave.com",
    },
    "contact_person": [{
        "contact_type": "technical",
        "given_name": "Russel",
        "sur_name": "Mahmud",
        "email_address": "russel_1237@hotmail.com"
    }, {
        "contact_type": "support",
        "given_name": "Support",
        "email_address": "adrian@carrierwave.com"
    }],
    "xmlsec_binary": xmlsec_path
}


__author__ = 'roland'

com_list = [xmlpath, "encrypt", "--pubkey-cert-pem", enc_key,
            "--session-key", key_type, "--xml-data", fil,
            "--node-xpath", ASSERT_XPATH]

(_stdout, _stderr, output) = self._run_xmlsec(com_list, [tmpl],
                                              exception=EncryptError,
                                              validate_output=False)



from saml2 import BINDING_SOAP, BINDING_HTTP_REDIRECT, BINDING_HTTP_POST
from saml2.saml import NAMEID_FORMAT_PERSISTENT
from saml2.saml import NAME_FORMAT_URI

try:
    from saml2.sigver import get_xmlsec_binary
    xmlsec_path = get_xmlsec_binary(["/opt/local/bin"])
except ImportError:
    xmlsec_path = '/usr/bin/xmlsec1'

BASE = "http://lingon.catalogix.se:8087"

CONFIG = {
    "entityid" : "urn:mace:example.com:saml:roland:idp",
    "name" : "Rolands IdP",
    "service": {
        "idp": {
            "endpoints" : {
                "single_sign_on_service" : [
                    ("%s/sso" % BASE, BINDING_HTTP_REDIRECT)],
                "single_logout_service": [
                    ("%s/slo" % BASE, BINDING_SOAP),
                    ("%s/slop" % BASE,BINDING_HTTP_POST)]
            },
            "policy": {
                "default": {
                    "lifetime": {"minutes":15},
                    "attribute_restrictions": None, # means all I have
                    "name_format": NAME_FORMAT_URI,
                    },
                "urn:mace:example.com:saml:roland:sp": {
                    "lifetime": {"minutes": 5},
                    "nameid_format": NAMEID_FORMAT_PERSISTENT,
                    # "attribute_restrictions":{
                    #     "givenName": None,
                    #     "surName": None,
                    # }
                }
            },
            "subject_data": "subject_data.db",
            },
        },
    "debug" : 1,
    "key_file" : "test.key",
    "cert_file" : "test.pem",
    "xmlsec_binary" : xmlsec_path,
    "metadata": {
        "local": ["metadata.xml", "vo_metadata.xml"],
        },
    "attribute_map_dir" : "attributemaps",
    "organization": {
        "name": "Exempel AB",
        "display_name": [("Exempel AB","se"),("Example Co.","en")],
        "url":"http://www.example.com/roland",
        },
    "contact_person": [{
                           "given_name":"John",
                           "sur_name": "Smith",
                           "email_address": ["john.smith@example.com"],
                           "contact_type": "technical",
                           },
                       ],
    }



from saml2.sigver import make_temp, pre_encryption_part
from saml2.saml import EncryptedAssertion
from saml2 import sigver, class_name, extension_elements_to_elements
from saml2 import samlp
from saml2 import saml
from saml2 import config
from saml2.mdstore import MetadataStore
from saml2.s_utils import factory
from saml2.s_utils import do_attribute_statement

__author__ = 'roland'


# load SP configuration
conf = config.SPConfig()
conf.load_file("server_conf")
# load metadata
md = MetadataStore([saml, samlp], None, conf)
md.load("local", "idp_example.xml")
conf.metadata = md

# setup the security context
sec = sigver.security_context(conf)

# Create a dummy assertion
assertion = factory(
    saml.Assertion, version="2.0", id="11111",
    issue_instant="2009-10-30T13:20:28Z",
    signature=sigver.pre_signature_part("11111", sec.my_cert, 1),
    attribute_statement=do_attribute_statement(
        {("", "", "surName"): ("Foo", ""),
         ("", "", "givenName"): ("Bar", ""), })
)

# Sign the assertion using the IdPs private key
sigass = sec.sign_statement(assertion, class_name(assertion),
                            key_file="pki/mykey.pem", node_id=assertion.id)

# Create an Assertion instance from the signed assertion
_ass = saml.assertion_from_string(sigass)
# Put the signed assertion in an EncryptedAssertion instance
encrypted_assertion = EncryptedAssertion()
# Have to be added as an extension element since that is what the
# EncryptedAssertion can hold
encrypted_assertion.add_extension_element(_ass)

# create the encrypt data template
_, pre = make_temp("%s" % pre_encryption_part(), decode=False)
# Encrypt the Assertion
enctext = sec.crypto.encrypt(
    "%s" % encrypted_assertion, conf.cert_file, pre, "des-192",
    '/*[local-name()="EncryptedAssertion"]/*[local-name()="Assertion"]')

# So this is where it turns around and the following lines should
# eventually produce a readable assertion
# Decrypt the encrypted assertion
decr_text = sec.decrypt(enctext)

# Create an EncryptedAssertion class instance
_seass = saml.encrypted_assertion_from_string(decr_text)
assertions = []

# convert the extension elements in to Assertion instances
assers = extension_elements_to_elements(_seass.extension_elements,
                                        [saml, samlp])

# The signers (the IDPs) cert == public key
sign_cert_file = "pki/mycert.pem"

for ass in assers:
    _ass = "%s" % ass
    # verify the signature
    _flag = sec.verify_signature(_ass, sign_cert_file,
                                 node_name=class_name(assertion))
    if _flag:  # The signature was correct
        assertions.append(ass)

for a in assertions:
    print a



# coding=utf-8
from saml2.authn_context import INTERNETPROTOCOLPASSWORD
from saml2 import saml
from saml2 import samlp
from saml2.server import Server

__author__ = 'roland'

AUTHN = {
    "class_ref": INTERNETPROTOCOLPASSWORD,
    "authn_auth": "http://www.example.com/login"
}


def test():
    server = Server("eduid")

    ava = {u'displayName': u'Stefan Liström',
           u'eduPersonPrincipalName': u'ginon-sukuh@eduid.se',
           u'givenName': u'Stefan',
           u'mail': u'stefan@listrom.se',
           "sn": u'Liström',
           'eduPersonScopedAffiliation': "staff@example.com",
    #       'eduPersonAffiliation': "staff"
    }

    npolicy = samlp.NameIDPolicy(format=saml.NAMEID_FORMAT_TRANSIENT,
                                 allow_create="true")

    resp = server.create_authn_response(
        ava, "_f49f31e0951e6ad3665b07499ad1f962",
        "https://connect.sunet.se/Shibboleth.sso/SAML2/POST" ,
        'https://connect.sunet.se/shibboleth',
        npolicy, '532d7e9d1fb33aeefd88a33e', authn=AUTHN)

    print(resp)

if __name__ == "__main__":
    test()


#!/usr/bin/env python
import os
from Crypto import Random
from Crypto.Cipher import AES
from base64 import b64encode, b64decode

__author__ = 'rolandh'

POSTFIX_MODE = {
    "cbc": AES.MODE_CBC,
    "cfb": AES.MODE_CFB,
    "ecb": AES.MODE_CFB,
}

BLOCK_SIZE = 16


class AESCipher(object):
    def __init__(self, key, iv=""):
        """

        :param key: The encryption key
        :param iv: Init vector
        :return: AESCipher instance
        """
        self.key = key
        self.iv = iv

    def build_cipher(self, iv="", alg="aes_128_cbc"):
        """
        :param iv: init vector
        :param alg: cipher algorithm
        :return: A Cipher instance
        """
        typ, bits, cmode = alg.split("_")

        if not iv:
            if self.iv:
                iv = self.iv
            else:
                iv = Random.new().read(AES.block_size)
        else:
            assert len(iv) == AES.block_size

        if bits not in ["128", "192", "256"]:
            raise Exception("Unsupported key length")
        try:
            assert len(self.key) == int(bits) >> 3
        except AssertionError:
            raise Exception("Wrong Key length")

        try:
            return AES.new(self.key, POSTFIX_MODE[cmode], iv), iv
        except KeyError:
            raise Exception("Unsupported chaining mode")


    def encrypt(self, msg, iv=None, alg="aes_128_cbc", padding="PKCS#7",
                b64enc=True, block_size=BLOCK_SIZE):
        """
        :param key: The encryption key
        :param iv: init vector
        :param msg: Message to be encrypted
        :param padding: Which padding that should be used
        :param b64enc: Whether the result should be base64encoded
        :param block_size: If PKCS#7 padding which block size to use
        :return: The encrypted message
        """

        if padding == "PKCS#7":
            _block_size = block_size
        elif padding == "PKCS#5":
            _block_size = 8
        else:
            _block_size = 0

        if _block_size:
            plen = _block_size - (len(msg) % _block_size)
            c = chr(plen)
            msg += c*plen

        cipher, iv = self.build_cipher(iv, alg)
        cmsg = iv + cipher.encrypt(msg)
        if b64enc:
            return b64encode(cmsg)
        else:
            return cmsg


    def decrypt(self, msg, iv=None, alg="aes_128_cbc", padding="PKCS#7", b64dec=True):
        """
        :param key: The encryption key
        :param iv: init vector
        :param msg: Base64 encoded message to be decrypted
        :return: The decrypted message
        """
        if b64dec:
            data = b64decode(msg)
        else:
            data = msg

        _iv = data[:AES.block_size]
        if iv:
            assert iv == _iv
        cipher, iv = self.build_cipher(iv, alg=alg)
        res = cipher.decrypt(data)[AES.block_size:]
        if padding in ["PKCS#5", "PKCS#7"]:
            res = res[:-ord(res[-1])]
        return res

if __name__ == "__main__":
    key_ = "1234523451234545"  # 16 byte key
    # Iff padded, the message doesn't have to be multiple of 16 in length
    msg_ = "ToBeOrNotTobe W.S."
    aes = AESCipher(key_)
    iv_ = os.urandom(16)
    encrypted_msg = aes.encrypt(key_, msg_, iv_)
    txt = aes.decrypt(key_, encrypted_msg, iv_)
    assert txt == msg_

    encrypted_msg = aes.encrypt(key_, msg_, 0)
    txt = aes.decrypt(key_, encrypted_msg, 0)
    assert txt == msg_



#!/usr/bin/env python
import re

import sys

from setuptools import setup
from setuptools.command.test import test as TestCommand

install_requires = [
    # core dependencies
    'decorator',
    'requests >= 1.0.0',
    'paste',
    'zope.interface',
    'repoze.who',
    'pycrypto >= 2.5',  # 'Crypto'
    'pytz',
    'pyOpenSSL',
    'python-dateutil',
    'six'
]

version = ''
with open('src/saml2/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

setup(
    name='pysaml2',
    version=version,
    description='Python implementation of SAML Version 2',
    # long_description = read("README"),
    author='Roland Hedberg',
    author_email='roland.hedberg@adm.umu.se',
    license='Apache 2.0',
    url='https://github.com/rohe/pysaml2',

    packages=['saml2', 'saml2/xmldsig', 'saml2/xmlenc', 'saml2/s2repoze',
              'saml2/s2repoze.plugins', "saml2/profile", "saml2/schema",
              "saml2/extension", "saml2/attributemaps", "saml2/authn_context",
              "saml2/entity_category", "saml2/userinfo", "saml2/ws"],

    package_dir={'': 'src'},
    package_data={'': ['xml/*.xml']},
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: Apache Software License",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5"
    ],

    scripts=["tools/parse_xsd2.py", "tools/make_metadata.py",
             "tools/mdexport.py", "tools/merge_metadata.py"],
    install_requires=install_requires,
    zip_safe=False,
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from saml2 import BINDING_HTTP_REDIRECT, BINDING_URI
from saml2 import BINDING_HTTP_ARTIFACT
from saml2 import BINDING_HTTP_POST
from saml2 import BINDING_SOAP
from saml2.saml import NAME_FORMAT_URI
from saml2.saml import NAMEID_FORMAT_TRANSIENT
from saml2.saml import NAMEID_FORMAT_PERSISTENT
import os.path

try:
    from saml2.sigver import get_xmlsec_binary
except ImportError:
    get_xmlsec_binary = None

if get_xmlsec_binary:
    xmlsec_path = get_xmlsec_binary(["/opt/local/bin"])
else:
    xmlsec_path = '/usr/bin/xmlsec1'

BASEDIR = os.path.abspath(os.path.dirname(__file__))


def full_path(local_file):
    return os.path.join(BASEDIR, local_file)

HOST = 'localhost'
PORT = 8088

BASE = "http://%s:%s" % (HOST, PORT)
HTTPS = True

if HTTPS:
    BASE = "https://%s:%s" % (HOST, PORT)
else:
    BASE = "http://%s:%s" % (HOST, PORT)

# HTTPS cert information
SERVER_CERT = "pki/mycert.pem"
SERVER_KEY = "pki/mykey.pem"
CERT_CHAIN = ""

CONFIG = {
    "entityid": "%s/idp.xml" % BASE,
    "description": "My IDP",
    "valid_for": 168,
    "service": {
        "aa": {
            "endpoints": {
                "attribute_service": [
                    ("%s/attr" % BASE, BINDING_SOAP)
                ]
            },
            "name_id_format": [NAMEID_FORMAT_TRANSIENT,
                               NAMEID_FORMAT_PERSISTENT]
        },
        "aq": {
            "endpoints": {
                "authn_query_service": [
                    ("%s/aqs" % BASE, BINDING_SOAP)
                ]
            },
        },
        "idp": {
            "name": "Rolands IdP",
            "endpoints": {
                "single_sign_on_service": [
                    ("%s/sso/redirect" % BASE, BINDING_HTTP_REDIRECT),
                    ("%s/sso/post" % BASE, BINDING_HTTP_POST),
                    ("%s/sso/art" % BASE, BINDING_HTTP_ARTIFACT),
                    ("%s/sso/ecp" % BASE, BINDING_SOAP)
                ],
                "single_logout_service": [
                    ("%s/slo/soap" % BASE, BINDING_SOAP),
                    ("%s/slo/post" % BASE, BINDING_HTTP_POST),
                    ("%s/slo/redirect" % BASE, BINDING_HTTP_REDIRECT)
                ],
                "artifact_resolve_service": [
                    ("%s/ars" % BASE, BINDING_SOAP)
                ],
                "assertion_id_request_service": [
                    ("%s/airs" % BASE, BINDING_URI)
                ],
                "manage_name_id_service": [
                    ("%s/mni/soap" % BASE, BINDING_SOAP),
                    ("%s/mni/post" % BASE, BINDING_HTTP_POST),
                    ("%s/mni/redirect" % BASE, BINDING_HTTP_REDIRECT),
                    ("%s/mni/art" % BASE, BINDING_HTTP_ARTIFACT)
                ],
                "name_id_mapping_service": [
                    ("%s/nim" % BASE, BINDING_SOAP),
                ],
            },
            "policy": {
                "default": {
                    "lifetime": {"minutes": 15},
                    "attribute_restrictions": None,  # means all I have
                    "name_format": NAME_FORMAT_URI,
                    "entity_categories": ["swamid", "edugain"],
                    "fail_on_missing_requested": False
                },
            },
            "subject_data": "./idp.subject",
            "name_id_format": [NAMEID_FORMAT_TRANSIENT,
                               NAMEID_FORMAT_PERSISTENT],
            "want_authn_requests_signed": False,
            'domain': 'example.com'
        },
    },
    "debug": 1,
    "key_file": full_path("pki/mykey.pem"),
    "cert_file": full_path("pki/mycert.pem"),
    "metadata": {
        #"local": [full_path("../sp-wsgi/sp.xml")],
        #"local": ["/Users/rolandh/code/freeradius_pysaml2/sp.xml"],
        #"local": ["/Users/rolandh/code/idp_monitor/localhost_sp.xml"],
        #"local": ["/Users/rolandh/code/inacademia/sp.xml"]
        #"local": ["/Users/rolandh/code/s2sproxy/proxy.xml"]
        #"local": ["/Users/rolandh/code/saml2test/testtool/test_idp/sp/cl/sp.xml"],
        "local": [
            "/Users/rolandh/code/saml2test/testtool/idp_test/sps.xml"
        ],
    },
    "organization": {
        "display_name": "Rolands Identiteter",
        "name": "Rolands Identiteter",
        "url": "http://www.example.com",
    },
    "contact_person": [
        {
            "contact_type": "technical",
            "given_name": "Roland",
            "sur_name": "Hedberg",
            "email_address": "technical@example.com"
        }, {
            "contact_type": "support",
            "given_name": "Support",
            "email_address": "support@example.com"
        },
    ],
    "xmlsec_binary": xmlsec_path,
    #"attribute_map_dir": "../attributemaps",
    "logger": {
        "rotating": {
            "filename": "idp.log",
            "maxBytes": 500000,
            "backupCount": 5,
        },
        "loglevel": "debug",
    }
}

# Authentication contexts

    #(r'verify?(.*)$', do_verify),

# CAS_SERVER = "https://cas.umu.se"
# CAS_VERIFY = "%s/verify_cas" % BASE
PWD_VERIFY = "%s/verify_pwd" % BASE

AUTHORIZATION = {
    #"CAS" : {"ACR": "CAS", "WEIGHT": 1, "URL": CAS_VERIFY},
    "UserPassword": {"ACR": "PASSWORD", "WEIGHT": 2, "URL": PWD_VERIFY}
}
